Package: mclustcomp
Type: Package
Title: Measures for Comparing Clusters
Version: 0.3.5
Authors@R: person("Kisung", "You", email = "kisung.you@outlook.com", role = c("aut", "cre"))
Description: Given a set of data points, a clustering is defined as a disjoint partition
    where each pair of sets in a partition has no overlapping elements. 
    This package provides 25 methods that play a role somewhat similar to 
    distance or metric that measures similarity of two clusterings - or partitions.
    For a more detailed description, see Meila, M. (2005) <doi:10.1145/1102351.1102424>.
License: MIT + file LICENSE
Encoding: UTF-8
Imports: Rcpp, Rdpack
LinkingTo: Rcpp, RcppArmadillo
RoxygenNote: 7.3.2
RdMacros: Rdpack
NeedsCompilation: yes
Packaged: 2025-09-22 01:24:16 UTC; kyou
Author: Kisung You [aut, cre]
Maintainer: Kisung You <kisung.you@outlook.com>
Repository: CRAN
Date/Publication: 2025-09-22 07:20:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 00:09:28 UTC; unix
Archs: mclustcomp.so.dSYM
