
<!-- README.md is generated from README.Rmd. Please edit that file -->
mclustcomp
==========

[![CRAN\_Status\_Badge](http://www.r-pkg.org/badges/version/mclustcomp?color=green)](https://cran.r-project.org/package=mclustcomp) [![Travis-CI Build Status](https://travis-ci.org/kisungyou/mclustcomp.svg?branch=master)](https://travis-ci.org/kisungyou/mclustcomp) [![](https://cranlogs.r-pkg.org/badges/mclustcomp)](https://cran.r-project.org/package=mclustcomp)

Installation
------------

You can install the released version of mclustcomp from [CRAN](https://CRAN.R-project.org) with:

``` r
install.packages("mclustcomp")
```

or the development version from github:

``` r
## install.packages("devtools")
## library(devtools)
devtools::install_github("kisungyou/mclustcomp")
```
