# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' Compute community size of a clustering
#'
#' @keywords internal
get.commsize <- function(x, ux) {
    .Call('_mclustcomp_getcommsize', PACKAGE = 'mclustcomp', x, ux)
}

#' Comembership matrix of size \code{(2-by-2)}
#'
#' @keywords internal
get.pair <- function(x, y) {
    .Call('_mclustcomp_getpair', PACKAGE = 'mclustcomp', x, y)
}

#' Compute confusion matrix
#'
#' @keywords internal
get.probs <- function(confmat, scx, scy, n, threps) {
    .Call('_mclustcomp_getprobs', PACKAGE = 'mclustcomp', confmat, scx, scy, n, threps)
}

get.confusion <- function(x, y, ux, uy) {
    .Call('_mclustcomp_genconfusion', PACKAGE = 'mclustcomp', x, y, ux, uy)
}

