% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{get.commsize}
\alias{get.commsize}
\title{Compute community size of a clustering}
\usage{
get.commsize(x, ux)
}
\description{
Compute community size of a clustering
}
\keyword{internal}
