% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{get.confusion}
\alias{get.confusion}
\title{Compute confusion matrix}
\usage{
get.confusion(x, y, ux, uy)
}
\description{
Compute confusion matrix
}
\keyword{internal}
