% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{get.pair}
\alias{get.pair}
\title{Comembership matrix of size \code{(2-by-2)}}
\usage{
get.pair(x, y)
}
\description{
Comembership matrix of size \code{(2-by-2)}
}
\keyword{internal}
