% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{get.probs}
\alias{get.probs}
\title{Compute confusion matrix}
\usage{
get.probs(confmat, scx, scy, n, threps)
}
\description{
Compute confusion matrix
}
\keyword{internal}
